.. _getting_started:


###############
Getting started
###############

.. _installing-ttcrpy:

*****************
Installing ttcrpy
*****************

You can use pip to install the package by doing::

  pip install ttcrpy

Requirements
============

ttcrpy needs the following modules:
  - numpy (https://numpy.org)
  - scipy (https://www.scipy.org)
  - vtk (https://www.vtk.org)
